DHallSyntaxKind

Enum DHallSyntaxKind 

pub enum DHallSyntaxKind {
Show 69 variants Whitespace, Newline, Comment, Identifier, Number, String, If, Then, Else, Let, In, Using, As, Merge, Some, None, NaN, Infinity, Type, Kind, Sort, Bool, Natural, Integer, Double, Text, List, Optional, True, False, With, Forall, Assert, Arrow, FatArrow, EqualEqual, NotEqual, And, Or, Append, Combine, CombineTypes, Prefer, Lambda, LeftParen, RightParen, LeftBrace, RightBrace, LeftBracket, RightBracket, Comma, Semicolon, Dot, Colon, Equal, Less, Greater, Plus, Minus, Star, Slash, Pipe, At, Hash, Question, Error, Eof, Root, SourceFile,
}

Variants



Whitespace

Whitespace characters



Newline

Newline character



Comment

Comment text



Identifier

Identifier name



Number

Number literal



String

String literal



If

The ‘if’ keyword



Then

The ‘then’ keyword



Else

The ‘else’ keyword



Let

The ‘let’ keyword



In

The ‘in’ keyword



Using

The ‘using’ keyword



As

The ‘as’ keyword



Merge

The ‘merge’ keyword



Some

The ‘Some’ keyword



None

The ‘None’ keyword



NaN

The ‘NaN’ keyword



Infinity

The ‘Infinity’ keyword



Type

The ‘Type’ keyword



Kind

The ‘Kind’ keyword



Sort

The ‘Sort’ keyword



Bool

The ‘Bool’ keyword



Natural

The ‘Natural’ keyword



Integer

The ‘Integer’ keyword



Double

The ‘Double’ keyword



Text

The ‘Text’ keyword



List

The ‘List’ keyword



Optional

The ‘Optional’ keyword



True

The ‘True’ keyword



False

The ‘False’ keyword



With

The ‘with’ keyword



Forall

The ‘forall’ keyword



Assert

The ‘assert’ keyword



Arrow

Arrow operator (-> or →)



FatArrow

Fat arrow operator (=>)



EqualEqual

Equality operator (== or ≡)



NotEqual

Inequality operator (!=)



And

Logical AND (&& or ∧)



Or

Logical OR (|| or ∨)



Append

List concatenation (++)



Combine

Record combination (// or ⫽)



CombineTypes

Type combination (/\ or ⩓)



Prefer

Record preference (//)



Lambda

Lambda operator (\ or λ)



LeftParen

Left parenthesis (()



RightParen

Right parenthesis ())



LeftBrace

Left brace ({)



RightBrace

Right brace (})



LeftBracket

Left bracket ([)



RightBracket

Right bracket (])



Comma

Comma (,)



Semicolon

Semicolon (;)



Dot

Dot (.)



Colon

Colon (:)



Equal

Assignment operator (=)



Less

Less than operator (<)



Greater

Greater than operator (>)



Plus

Plus operator (+)



Minus

Minus operator (-)



Star

Multiplication operator (*)



Slash

Division operator (/)



Pipe

Pipe operator (|)



At

At symbol (@)



Hash

Hash symbol (#)



Question

Question mark (?)



Error

Error token



Eof

End of file marker



Root



SourceFile

Implementations